@@ -3,7 +3,7 @@
 ;; Copyright (C) 2021 Free Software Foundation, Inc.
 
 ;; Author: Tyler Grinn <tylergrinn@gmail.com>
-;; Version: 1.1.0
+;; Version: 1.1.1
 ;; File: boxy.el
 ;; Package-Requires: ((emacs "26.1"))
 ;; Keywords: tools
@@ -207,7 +207,7 @@
 
 ;;;; Custom types
 
-(defun boxy-relationshipp (str)
+(defun boxy-relationship-p (str)
   "Return t if STR is a boxy relationship, nil otherwise."
   (member str boxy-relationships))
 
